# coding: utf-8

from recastai import Action


class TestAction(object):
  def test_instanciable(self):
    Action({'slug': 'greetings', 'done': True, 'reply': 'Hello there!'})

  def test_attributes(self):
    action = Action({'slug': 'greetings', 'done': True, 'reply': 'Hello there!'})

    assert(action.slug == 'greetings')
    assert(action.done == True)
    assert(action.reply == 'Hello there!')



# coding: utf-8

import json
from recastai import Conversation
from recastai import Action
from recastai import Intent
from recastai import Entity


class TestConversation(object):
  def test_instanciable(self):
    Conversation(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in Paris ?', 'replies': ['Do you already have an account?', 'This is a test?'], 'action': {'slug': 'murder', 'done': False, 'reply': 'do you already have an account?'}, 'next_actions': [{'slug': 'test', 'done': False, 'reply': 'This is a test?'}], 'memory':{'victim': None, 'client': None, 'mail-client': None, 'lieu': {'lat': 0.54, 'lng': 0.435}}, 'entities': {}, 'intents': [], 'conversation_token': '8641d38b059cde2826e3cdf2f9b00725', 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-10-04T15:26:11.876Z', 'status': 200}, 'message': 'Converses rendered with success'}))

  def test_attributes(self):
    conversation = Conversation(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in Paris ?', 'replies': ['Do you already have an account?', 'This is a test?'], 'action': {'slug': 'murder', 'done': False, 'reply': 'do you already have an account?'}, 'next_actions': [{'slug': 'test', 'done': False, 'reply': 'This is a test?'}], 'memory':{'victim': None, 'client': None, 'mail-client': None, 'lieu': {'lat': 0.54, 'lng': 0.435}}, 'entities': {}, 'intents': [], 'conversation_token': '8641d38b059cde2826e3cdf2f9b00725', 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-10-04T15:26:11.876Z', 'status': 200}, 'message': 'Converses rendered with success'}))

    assert(conversation.raw == json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in Paris ?', 'replies': ['Do you already have an account?', 'This is a test?'], 'action': {'slug': 'murder', 'done': False, 'reply': 'do you already have an account?'}, 'next_actions': [{'slug': 'test', 'done': False, 'reply': 'This is a test?'}], 'memory':{'victim': None, 'client': None, 'mail-client': None, 'lieu': {'lat': 0.54, 'lng': 0.435}}, 'entities': {}, 'intents': [], 'conversation_token': '8641d38b059cde2826e3cdf2f9b00725', 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-10-04T15:26:11.876Z', 'status': 200}, 'message': 'Converses rendered with success'}))
    assert(conversation.uuid == 'db4837b0-8359-4505-9678-c4081a6f2ad8')
    assert(conversation.source == 'What is the weather in Paris ?')
    assert(type(conversation.replies) is list)
    assert(type(conversation.replies[0]) is str)
    assert(type(conversation.action) is Action)
    assert(type(conversation.next_actions) is list)
    assert(type(conversation.next_actions[0]) is Action)
    assert(type(conversation.memory) is list)
    assert(type(conversation.memory[0]) is Entity)
    assert(type(conversation.entities) is list)
    assert(type(conversation.intents) is list)
    assert(conversation.conversation_token == '8641d38b059cde2826e3cdf2f9b00725')
    assert(conversation.language == 'en')
    assert(conversation.version == '2.0.0')
    assert(conversation.timestamp == '2016-10-04T15:26:11.876Z')
    assert(conversation.status == 200)

  def test_helpers(self):
    conversation = Conversation(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in Paris ?', 'replies': ['Do you already have an account?', 'This is a test?'], 'action': {'slug': 'murder', 'done': False, 'reply': 'do you already have an account?'}, 'next_actions': [{'slug': 'test', 'done': False, 'reply': 'This is a test?'}], 'memory':{'victim': None, 'client': None, 'mail-client': None, 'lieu': {'lat': 0.54, 'lng': 0.435}}, 'entities': {}, 'intents': [], 'conversation_token': '8641d38b059cde2826e3cdf2f9b00725', 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-10-04T15:26:11.876Z', 'status': 200}, 'message': 'Converses rendered with success'}))

    assert(conversation.reply() == conversation.replies[0])
    assert(conversation.next_action() == conversation.next_actions[0])
    assert(conversation.joined_replies() == ' '.join(conversation.replies))
    assert(conversation.joined_replies("\n") == "\n".join(conversation.replies))
    assert(conversation.get_memory() == conversation.memory)
    assert(conversation.get_memory('lieu') == [entity for entity in conversation.memory if entity.name.lower() == 'lieu'][0])
    assert(conversation.intent() == None)

  def test_missing(self):
    conversation = Conversation(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in Paris ?', 'replies': [], 'action': None, 'next_actions': [], 'memory':{'victim': None, 'client': None, 'mail-client': None, 'lieu': []}, 'entities': {}, 'intents': [], 'conversation_token': '8641d38b059cde2826e3cdf2f9b00725', 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-10-04T15:26:11.876Z', 'status': 200}, 'message': 'Converses rendered with success'}))
    assert(conversation.action is None)
    assert(conversation.reply() is None)
    assert(conversation.intent() is None)
    assert(conversation.next_action() is None)

  def test_static_methods(self):
    assert(getattr(Conversation, 'set_memory') != None)
    assert(getattr(Conversation, 'reset_memory') != None)
    assert(getattr(Conversation, 'reset_conversation') != None)



# coding: utf-8

import pytest
import sys
import os
import json
import responses
from recastai import Client
from recastai import Response
from recastai import Conversation
from recastai import RecastError


class TestClient(object):
  def test_instanciable(self):
    Client()

  def test_attributes(self):
    client = Client()

    client.token
    client.language

  def test_missing(self):
    client = Client()

    with pytest.raises(RecastError):
      client.text_request('This is my text')

    with pytest.raises(RecastError):
      client.file_request(os.path.dirname(os.path.realpath(__file__)) + '/../utils/test.wav')

    with pytest.raises(RecastError):
      client.text_converse('This is my text')

  @responses.activate
  def test_bad_request(self):
    client = Client('testtoken')

    body = json.dumps({'results': None, 'message': 'Request is invalid'})
    responses.add(responses.POST, 'https://api.recast.ai/v2/request', body=body, status=400)
    responses.add(responses.POST, 'https://api.recast.ai/v2/converse', body=body, status=400)

    with pytest.raises(RecastError):
      client.text_request('This is my text')

    with pytest.raises(RecastError):
      client.file_request(os.path.dirname(os.path.realpath(__file__)) + '/../utils/test.wav')

    with pytest.raises(RecastError):
      client.text_converse('This is my text')

  @responses.activate
  def test_text_request(self):
    client = Client('testtoken')

    body = json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [{'slug': 'weather', 'confidence': 0.67}], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'})
    responses.add(responses.POST, 'https://api.recast.ai/v2/request', body=body, status=200)

    response = client.text_request('This is my text')

    assert(type(response) == Response)

  @responses.activate
  def test_file_request(self):
    client = Client('testtoken')

    body = json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [{'slug': 'weather', 'confidence': 0.67}], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'})
    responses.add(responses.POST, 'https://api.recast.ai/v2/request', body=body, status=200)

    response = client.file_request(os.path.dirname(os.path.realpath(__file__)) + '/../utils/test.wav')

    assert(type(response) == Response)

  @responses.activate
  def test_text_converse(self):
    client = Client('testtoken')

    body = json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in Paris ?', 'replies': ['Do you already have an account?', 'This is a test?'], 'action': {'slug': 'murder', 'done': False, 'reply': 'do you already have an account?'}, 'next_actions': [{'slug': 'test', 'done': False, 'reply': 'This is a test?'}], 'memory':{'victim': None, 'client': None, 'mail-client': None, 'lieu': {'lat': 0.54, 'lng': 0.435}}, 'entities': {}, 'intents': [], 'conversation_token': '8641d38b059cde2826e3cdf2f9b00725', 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-10-04T15:26:11.876Z', 'status': 200}, 'message': 'Converses rendered with success'})
    responses.add(responses.POST, 'https://api.recast.ai/v2/converse', body=body, status=200)

    response = client.text_converse('What is the weather in Paris?')

    assert(type(response) == Conversation)

  @responses.activate
  def test_overrides(self):
    client = Client('testtoken')

    body = json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [{'slug': 'weather', 'confidence': 0.67}], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'})
    responses.add(responses.POST, 'https://api.recast.ai/v2/request', body=body, status=200)
    body = json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in Paris ?', 'replies': ['Do you already have an account?', 'This is a test?'], 'action': {'slug': 'murder', 'done': False, 'reply': 'do you already have an account?'}, 'next_actions': [{'slug': 'test', 'done': False, 'reply': 'This is a test?'}], 'memory':{'victim': None, 'client': None, 'mail-client': None, 'lieu': {'lat': 0.54, 'lng': 0.435}}, 'entities': {}, 'intents': [], 'conversation_token': '8641d38b059cde2826e3cdf2f9b00725', 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-10-04T15:26:11.876Z', 'status': 200}, 'message': 'Converses rendered with success'})
    responses.add(responses.POST, 'https://api.recast.ai/v2/converse', body=body, status=200)

    text_response = client.text_request('This is my text', token='tokentest', language='fr')
    file_response = client.file_request(os.path.dirname(os.path.realpath(__file__)) + '/../utils/test.wav', token='tokentest', language='fr')
    text_conversation = client.text_converse('This is my text', token='tokentest', language='fr', conversation_token='conversationtokentest', memory={'lieu':{'lat': 0.54, 'lng': 0.435}})

    assert(type(text_response) == Response)
    assert(type(file_response) == Response)
    assert(type(text_conversation) == Conversation)



# coding: utf-8

from recastai import RecastError


class TestRecastError(object):
  def test_instanciable(self):
    RecastError('error')

  def test_message(self):
    e = RecastError('error')

    assert(str(e) == 'error')



# coding: utf-8

from .client import Client
from .response import Response
from .conversation import Conversation
from .action import Action
from .intent import Intent
from .entity import Entity
from .utils import Utils
from .errors import RecastError

__all__ = ['Client', 'Response', 'Conversation', 'Action', 'Intent', 'Entity', 'Utils', 'RecastError']

__title__ = 'recastai'
__author__ = 'Paul Renvoisé'
__version__ = Utils.VERSION
__license__ = 'MIT'
__copyright__ = 'Copyright 2016 Recast.AI'



# coding: utf-8

import json
import requests

from .action import Action
from .intent import Intent
from .entity import Entity
from .errors import RecastError
from .utils import Utils

class Conversation(object):
  def __init__(self, response):
    self.raw = response

    response = json.loads(response)
    response = response['results']

    self.uuid = response['uuid']
    self.source = response['source']
    self.replies = response['replies']
    self.action  = Action(response['action']) if response['action'] else None
    self.next_actions = [Action(a) for a in response['next_actions']]
    self.memory = [Entity(n, e) for n, e in response['memory'].items() if e]
    self.entities = [Entity(n, ee) for n, e in response['entities'].items() for ee in e]
    self.intents = [Intent(i) for i in response['intents']]
    self.conversation_token = response['conversation_token']
    self.language = response['language']
    self.version = response['version']
    self.timestamp = response['timestamp']
    self.status = response['status']

  def reply(self):
    try:
      return self.replies[0]
    except IndexError:
      return None

  def next_action(self):
    try:
      return self.next_actions[0]
    except IndexError:
      return None

  def joined_replies(self, sep=' '):
    return sep.join(self.replies)

  def get_memory(self, key=None):
    if key is None:
      return self.memory

    for entity in self.memory:
      if (entity.name.lower() == key.lower()):
        return entity

  def intent(self):
    try:
      return self.intents[0]
    except IndexError:
      return None

  @classmethod
  def set_memory(cls, token, conversation_token, memory):
    body = { 'conversation_token': conversation_token, 'memory': memory }
    response = requests.put(
      Utils.CONVERSE_ENDPOINT,
      json=body,
      headers={'Authorization': "Token {}".format(token)}
    )
    if response.status_code != requests.codes.ok:
      raise RecastError.new(response.reason)

    response = json.loads(response)
    response = response['results']
    return [Entity(n, e) for n, e in response['memory'].items() if e]

  @classmethod
  def reset_memory(cls, token, conversation_token, key=None):
    body = {'conversation_token': conversation_token}
    if key:
      body['memory'] = { key: None }
    response = requests.put(
      Utils.CONVERSE_ENDPOINT,
      json=body,
      headers={'Authorization': "Token {}".format(token) }
    )
    if response.status_code != requests.codes.ok:
      raise RecastError.new(response.reason)

    response = json.loads(response)
    response = response['results']
    return [Entity(n, e) for n, e in response['memory'].items() if e]

  @classmethod
  def reset_conversation(cls, token, conversation_token):
    body = {'conversation_token': conversation_token}
    response = requests.delete(
      Utils.CONVERSE_ENDPOINT,
      json=body,
      headers={'Authorization': "Token {}".format(token)}
    )
    if response.status_code != requests.codes.ok:
      raise RecastError.new(response.reason)

    response = json.loads(response)
    response = response['results']
    return [Entity(n, e) for n, e in response['memory'].items() if e]



# coding: utf-8

import json
from recastai import Response
from recastai import Intent
from recastai import Entity


class TestResponse(object):
  def test_instanciable(self):
    Response(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [{'slug': 'weather', 'confidence': 0.67}], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'}))

  def test_attributes(self):
    response = Response(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [{'slug': 'weather', 'confidence': 0.67}], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'}))

    assert(response.raw == json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [{'slug': 'weather', 'confidence': 0.67}], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'}))
    assert(response.source == 'What is the weather in London tomorrow? And in Paris?')
    assert(type(response.intents) is list)
    assert(type(response.intents[0]) is Intent)
    assert(response.act == 'wh-query')
    assert(response.type == 'desc:desc')
    assert(response.sentiment == 'neutral')
    assert(type(response.entities) is list)
    assert(type(response.entities[0]) is Entity)
    assert(response.language == 'en')
    assert(response.version == '2.0.0')
    assert(response.timestamp == '2016-07-10T23:17:59+02:00')
    assert(response.status == 200)

  def test_helpers(self):
    response = Response(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [{'slug': 'weather', 'confidence': 0.67}], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'}))

    assert(response.intent() == response.intents[0])
    entity = None
    for e in response.entities:
      if e.name.lower() == 'location':
        entity = e
        break
    assert(response.get('location') == entity)
    entities = []
    for e in response.entities:
      if e.name.lower() == 'location':
        entities.append(e)
    assert(response.all('location') == entities)
    assert(response.is_assert() == False)
    assert(response.is_command() == False)
    assert(response.is_wh_query() == True)
    assert(response.is_yn_query() == False)
    assert(response.is_abbreviation() == False)
    assert(response.is_entity() == False)
    assert(response.is_description() == True)
    assert(response.is_human() == False)
    assert(response.is_location() == False)
    assert(response.is_number() == False)
    assert(response.is_vpositive() == False)
    assert(response.is_positive() == False)
    assert(response.is_neutral() == True)
    assert(response.is_negative() == False)
    assert(response.is_vnegative() == False)

  def test_missing_array(self):
    response = Response(json.dumps({'results': {'uuid': 'db4837b0-8359-4505-9678-c4081a6f2ad8', 'source': 'What is the weather in London tomorrow? And in Paris?', 'intents': [], 'act': 'wh-query', 'type': 'desc:desc', 'sentiment': 'neutral', 'entities': {'action': [{'agent': 'the weather in London', 'tense': 'present', 'raw': 'is', 'confidence': 0.89}], 'location': [{'formated': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97}, {'formated': 'Paris, Paris, Île-de-France, France', 'lat': 48.856614, 'lng': 2.3522219, 'raw': 'Paris', 'confidence': 0.83}], 'datetime': [{'iso': '2016-07-11T10:00:00+00:00', 'raw': 'tomorrow', 'confidence': 0.95}]}, 'language': 'en', 'version': '2.0.0', 'timestamp': '2016-07-10T23:17:59+02:00', 'status': 200}, 'message': 'Requests rendered with success'}))
    assert(response.intent() is None)



# coding: utf-8

from recastai import Entity


class TestEntity(object):
  def test_instanciable(self):
    Entity('location', {'formatted': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97})

  def test_attributes(self):
    entity = Entity('location', {'formatted': 'London, London, Greater London, England, United Kingdom', 'lat': 51.5073509, 'lng': -0.1277583, 'raw': 'London', 'confidence': 0.97})

    assert(entity.name == 'location')
    assert(entity.formatted == 'London, London, Greater London, England, United Kingdom')
    assert(entity.lat == 51.5073509)
    assert(entity.lng == -0.1277583)
    assert(entity.raw == 'London')
    assert(entity.confidence == 0.97)



# coding: utf-8

import io
import requests

from .response import Response
from .conversation import Conversation
from .errors import RecastError
from .utils import Utils


class Client(object):
  def __init__(self, token=None, language=None):
    self.token = token
    self.language = language

  """
  Perform a text converse to Recast.AI
  """
  def text_converse(self, text, token=None, language=None, conversation_token=None, memory=None):
    token = token or self.token
    if token is None:
      raise RecastError("Token is missing")

    language = language or self.language

    body = {'text': text}
    if language is not None:
      body['language'] = language
    if conversation_token is not None:
      body['conversation_token'] = conversation_token
    if memory is not None:
      body['memory'] = memory

    response = requests.post(
      Utils.CONVERSE_ENDPOINT,
      json=body,
      headers={'Authorization': "Token {}".format(token)}
    )
    if response.status_code != requests.codes.ok:
      raise RecastError(response.reason)

    return Conversation(response.text)

  """
  Perform a text request to Recast.AI
  """
  def text_request(self, text, token=None, language=None):
    token = token or self.token
    if token is None:
      raise RecastError("Token is missing")

    language = language or self.language

    body = {'text': text}
    if language is not None:
      body['language'] = language

    response = requests.post(
      Utils.REQUEST_ENDPOINT,
      json=body,
      headers={'Authorization': "Token {}".format(token)}
    )
    if response.status_code != requests.codes.ok:
      raise RecastError(response.reason)

    return Response(response.text)

  """
  Perform a file request to Recast.AI
  """
  def file_request(self, filename, token=None, language=None):
    token = token or self.token
    if token is None:
      raise RecastError("Token is missing")

    language = language or self.language

    filename = open(filename, 'rb') if not isinstance(filename, io.IOBase) else filename
    body = { 'voice': filename }
    if language is not None:
      body['language'] = language

    response = requests.post(
      Utils.REQUEST_ENDPOINT,
      files=body,
      headers={'Authorization': "Token {}".format(token)}
    )
    if response.status_code != requests.codes.ok:
      raise RecastError(response.reason)

    return Response(response.text)



# coding: utf-8

from recastai import Intent


class TestIntent(object):
  def test_instanciable(self):
    Intent({'slug': 'weather', 'confidence': 0.67})

  def test_attributes(self):
    intent = Intent({'slug': 'weather', 'confidence': 0.67})

    assert(intent.slug == 'weather')
    assert(intent.confidence == 0.67)



from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), 'r', 'utf-8') as f:
    readme = f.read()

setup(
    name="recastai",
    version="2.2.2",
    packages=find_packages(),
    description="Recast.AI official SDK for python",
    long_description=readme,
    author="Paul Renvoise",
    author_email="paul.renvoise@recast.ai",
    url="https://github.com/RecastAI/sdk-python",
    license="MIT",
    install_requires=[
      "requests>=2.10",
      "pytest>=2.9",
      "pytest-cov>=2.2",
      "responses>=0.5"
    ],
    keywords="recastai bot nlp")
